2.24: release 2.23.8 2.24 debian/2%2.24-1
authorFrancois-Rene Rideau <fare@tunes.org>
Sat, 25 Aug 2012 23:54:48 +0000 (19:54 -0400)
committerFrancois-Rene Rideau <fare@tunes.org>
Sat, 25 Aug 2012 23:54:48 +0000 (19:54 -0400)
Makefile
asdf.asd
asdf.lisp
debian/changelog

index 7fd67ec..527bdf3 100644 (file)
--- a/Makefile
+++ b/Makefile
@@ -105,6 +105,8 @@ test-upgrade:
            echo "Testing upgrade from ASDF $${tag} using method $$x" ; \
            git show $${tag}:asdf.lisp > tmp/asdf-$${tag}.lisp ; \
            case ${lisp}:$$tag:$$x in \
+             abcl:2.0[01][1-9]|abcl:2.2[1-2]:*) \
+               : Skip, because it is so damn slow ;; \
              ccl:1.*|ccl:2.0[01]*) \
                : Skip, because ccl broke old asdf ;; \
              cmucl:1.*|cmucl:2.00*|cmucl:2.01[0-4]:*) \
index 175731a..abfc94a 100644 (file)
--- a/asdf.asd
+++ b/asdf.asd
@@ -14,7 +14,7 @@
   :licence "MIT"
   :description "Another System Definition Facility"
   :long-description "ASDF builds Common Lisp software organized into defined systems."
-  :version "2.23.8" ;; to be automatically updated by bin/bump-revision
+  :version "2.24" ;; to be automatically updated by bin/bump-revision
   :depends-on ()
   :components
   ((:file "asdf")
index d228876..a97632d 100644 (file)
--- a/asdf.lisp
+++ b/asdf.lisp
@@ -1,5 +1,5 @@
 ;;; -*- mode: Common-Lisp; Base: 10 ; Syntax: ANSI-Common-Lisp ; coding: utf-8 -*-
;;; This is ASDF 2.23.8: Another System Definition Facility.
 ;;;
 ;;; Feedback, bug reports, and patches are all welcome:
 ;;; please mail to <asdf-devel@common-lisp.net>.
          ;; "2.345.6" would be a development version in the official upstream
          ;; "2.345.0.7" would be your seventh local modification of official release 2.345
          ;; "2.345.6.7" would be your seventh local modification of development version 2.345.6
-         (asdf-version "2.23.8")
+         (asdf-version "2.24")
          (existing-asdf (find-class 'component nil))
          (existing-version *asdf-version*)
          (already-there (equal asdf-version existing-version)))
index 6b920c9..b6bae24 100644 (file)
@@ -1,3 +1,26 @@
+cl-asdf (2:2.24-1) unstable; urgency=low
+
+  * ACL: handle SMP vs non-SMP builds in Allegro 9.0
+  * MKCL: add support for ManKai Common Lisp
+  * ECL: merge improvements from ECL git. Refactor ECL support somewhat.
+  * Remove broken-fasl-support: first, cormanlisp is supposed to have fixed it;
+    second, cormanlisp is dead;
+    third, one can now (setf *load-system-operation* 'load-source-op) instead
+    while using asdf:load-system.
+  * renaming ends-with to string-suffix-p to avoid conflict with alexandria.
+  * Refactor load-system to use *load-system-operation*,
+    and change require-system and module-provide-asdf to use that.
+
+  Also note:
+  * We recommend you use asdf-utils to access the utilities in asdf.
+    Some time next year, we may stop exporting the utilities from asdf itself.
+  * To avoid conflicts between alexandria, fare-utils, xcvb-driver,
+    asdf-utils, etc., you can use xcvb-utils that solves the conflicts.
+    Or you can use fare-utils:define-package-mix that will help you
+    automatically resolve them.
+
+ -- Francois-Rene Rideau <fare@tunes.org>  Sat, 25 Aug 2012 08:05:21 -0400
+
 cl-asdf (2:2.23-1) unstable; urgency=low
 
   * add new :compile-check argument to compile-file* and around-compile-hook.
@@ -1,5 +1,5 @@
 ;;; -*- mode: Common-Lisp; Base: 10 ; Syntax: ANSI-Common-Lisp ; coding: utf-8 -*-
-;;; This is ASDF 2.23.8: Another System Definition Facility.
+;;; This is ASDF 2.24: Another System Definition Facility.
 ;;;
 ;;; Feedback, bug reports, and patches are all welcome: